// ----------------------------------------------------
// Processing Rennes du 4 au 5 Novembre 2011
// ----------------------------------------------------
// http://data.keolis-rennes.com/fr/les-donnees/donnees-et-api.html
// Unfolding : http://unfoldingmaps.org/ 
// GLGraphics : http://glgraphics.sourceforge.net/
// Triangulate : http://wiki.processing.org/w/Triangulation
// Pictos : http://data.keolis-rennes.com/fr/les-donnees/donnees-telechargeables/donnees-graphiques.html

import processing.opengl.*;
import codeanticode.glgraphics.*;
import de.fhpotsdam.unfolding.*;
import de.fhpotsdam.unfolding.geo.*;
import de.fhpotsdam.unfolding.utils.*;

String keolisCle = "####";
String keolisCommande = "getbikestations";
String keolisVersion = "2.0";
PImage keolisPictoVelo;

de.fhpotsdam.unfolding.Map carte;
ArrayList<Station> stationsListe;

void setup() 
{
  // Dimension de la fenêtre
  // Le mode de dessin est GLGRAPHICS, qui permet d'utiliser efficacement la carte vidéo
  size(800,600,GLConstants.GLGRAPHICS);

  // Création de la carte
  // Rennes est située à 48.100 de latitude et -1.667 de longitude
  carte = new de.fhpotsdam.unfolding.Map(this);
  carte.zoomAndPanTo(new Location(48.100f, -1.667f), 10);

  // Cette ligne de code permet d'avoir les comportements de navigation par défaut
  // Glisser / Déplacer + Zoom avec la mollette
  MapUtils.createDefaultEventDispatcher(this, carte);

  // Chargement des pictos
  keolisPictoVelo = loadImage("Picto B+M+P+Velo-100x100.png");

  // Addresse à laquelle nous allons accéder aux données
  String url = "http://data.keolis-rennes.com/xml/?version="+keolisVersion+"&key="+keolisCle+"&cmd="+keolisCommande;
  
  // Chargement des données dans un objet permettant de lire le XML
  XMLElement xml = new XMLElement(this, url);

  // On est prêt à analyser les données à présent
  // Nous accèdons d'abord aux noeuds <station>
   XMLElement[] stationsXML = xml.getChildren("answer/data/station");
   
   // Ici on va récupérer les informations relatives à une station (nom, latitude, longitude)
   // en parcourant la liste des stations
   stationsListe = new ArrayList<Station>();
   for (int i=0;i<stationsXML.length;i++){
     stationsListe.add(new Station(stationsXML[i]));
   }

}

void draw() 
{
  // Couleur de fond
  background(#dfdfdf);

  // Dessin de la carte
  carte.draw();

  // Dessin des sations
  // L'opacité d'un picto va dépendre de la disponibilité d'une station
  // soit le nombre de vélo disponible / nombre de vélos total
  for (Station s : stationsListe)
  {
   // Conversion latitude / longitude -> coordonnées en pixels sur la fenêtre
   float xy[] = carte.getScreenPositionFromLocation(s.position);
   
   // Calcul de l'opacité
   float a = 255.0*float(s.velosDisponibles)/float(s.velosDisponibles+s.slotsDisponibles);

    // Teinte pour le picto
   tint(255,255,255,a);
   
   // Affichage du picto pour cette station
   image(keolisPictoVelo,xy[0],xy[1],20,20);
  }
}

