// ----------------------------------------------------
// Processing Rennes du 4 au 5 Novembre 2011
// ----------------------------------------------------
// http://data.keolis-rennes.com/fr/les-donnees/donnees-et-api.html

// Unfolding : http://unfoldingmaps.org/ 
// GLGraphics : http://glgraphics.sourceforge.net/
// Triangulate : http://wiki.processing.org/w/Triangulation

// Pictos : http://data.keolis-rennes.com/fr/les-donnees/donnees-telechargeables/donnees-graphiques.html

import processing.opengl.*;
import org.processing.wiki.triangulate.*;
import codeanticode.glgraphics.*;
import de.fhpotsdam.unfolding.*;
import de.fhpotsdam.unfolding.geo.*;
import de.fhpotsdam.unfolding.utils.*;


String keolisCle = "####";
String keolisCommande = "getbikestations";
String keolisVersion = "2.0";
PImage keolisPictoVelo;

de.fhpotsdam.unfolding.Map carte;
ArrayList<Station> stationsListe;

boolean dessineTriangles = false;

void setup() 
{
  // Dimension de la fenêtre
  // Le mode de dessin est GLGRAPHICS, qui permet d'utiliser efficacement la carte vidéo
  size(800,600,GLConstants.GLGRAPHICS);

  // Création de la carte
  // Rennes est située à 48.100 de latitude et -1.667 de longitude
  carte = new de.fhpotsdam.unfolding.Map(this);
  carte.zoomAndPanTo(new Location(48.100f, -1.667f), 13);

  // Cette ligne de code permet d'avoir les comportements de navigation par défaut
  // Glisser / Déplacer + Zoom avec la mollette
  MapUtils.createDefaultEventDispatcher(this, carte);

  // Chargement des pictos
  keolisPictoVelo = loadImage("Picto B+M+P+Velo-100x100.png");

  // Addresse à laquelle nous allons accéder aux données
  String url = "http://data.keolis-rennes.com/xml/?version="+keolisVersion+"&key="+keolisCle+"&cmd="+keolisCommande;
  
  // Chargement des données dans un objet permettant de lire le XML
  XMLElement xml = new XMLElement(this, url);

  // On est prêt à analyser les données à présent
  // Nous accèdons d'abord aux noeuds <station>
   XMLElement[] stationsXML = xml.getChildren("answer/data/station");
   
   // Ici on va récupérer les informations relatives à une station (nom, latitude, longitude)
   // en parcourant la liste des stations
   stationsListe = new ArrayList<Station>();
   for (int i=0;i<stationsXML.length;i++){
     stationsListe.add(new Station(stationsXML[i]));
   }

}

void draw() 
{
  background(#dfdfdf);
  // Dessin de la carte
  //tint(255,100);
  carte.draw();

  // Dessin des triangles
  //stroke(0);
  noStroke();
  ArrayList triangles = triangulateStations();
  if (dessineTriangles)
  {
    beginShape(TRIANGLES);
    for (int i=0;i<triangles.size();i++)
    {
        Triangle t = (Triangle)triangles.get(i);

        Station p1s = getStationFromPoint(t.p1);
        Station p2s = getStationFromPoint(t.p2);
        Station p3s = getStationFromPoint(t.p3);

        fill(map(p1s.disponibilite(),0,1,100,255),0,0,200);vertex(t.p1.x, t.p1.y, 0.0);
        fill(map(p2s.disponibilite(),0,1,100,255),0,0,200);vertex(t.p2.x, t.p2.y, 0.0);
        fill(map(p3s.disponibilite(),0,1,100,255),0,0,200);vertex(t.p3.x, t.p3.y, 0.0);
    }
    endShape();
  }
  else
  {
    stroke(0);
    for (int i=0;i<triangles.size();i++)
    {
        Triangle t = (Triangle)triangles.get(i);
       line(t.p1.x, t.p1.y, t.p2.x, t.p2.y);
       line(t.p1.x, t.p1.y, t.p3.x, t.p3.y);
       line(t.p2.x, t.p2.y, t.p3.x, t.p3.y);
    } 
  }
}



